@@ -1,21 +1,52 @@
+import os
 import json
 import uuid
-import munch
 
+import logging
+from logging.config import dictConfig
+
+import munch
 from werkzeug.serving import run_simple
 from werkzeug.wrappers import Request, Response
 from werkzeug.exceptions import HTTPException, NotFound
 from werkzeug.routing import Map, Rule
 
-__version__ = '0.0.1'
+__version__ = '0.1.1'
+
+apiname = os.environ.get('SOLACE_API_NAME', str(uuid.uuid4()))
+
+
+DEFAULT_LOGGING = {
+    'version': 1,
+    'disable_existing_loggers': False,
+    'loggers': {
+        '': {
+            'level': os.environ.get('LOG_LEVEL', 'WARNING').upper(),
+        }
+    }
+}
+logging.config.dictConfig(DEFAULT_LOGGING)
+
+# try:
+#     log_level = os.environ['LOG_LEVEL'].upper()
+# except KeyError:
+#     log_level = "WARNING"
+#     log.warning("optional environment variable LOG_LEVEL was not set")
+# log.setLevel(logging.getLevelName(log_level))
+# log.warning("log level is set to {}".format(log_level))
+
+# TODO: catch any errors that may come from not passing the proper data type here
+# TODO: raise our own custom error types
+def objectify(dict):
+    return munch.munchify(dict)
 
 class SolaceResponse(Response):
-    json = None
+    json = munch.munchify({})
 
     def __init__(self,):
         super().__init__()
 
-class App:
+class Api:
     
     def __init__(self):
         self.rules = Map([])
@@ -95,21 +126,35 @@ class App:
         to a resource.
         """
         self.__rule('PATCH', urlpath, handler)
+    
+    def websocket(self, urlpath, handler):
+        # NOTE: Werkzeug has no further WebSocket support beyond routing.
+        # TODO: We'll need to bring in a Websocket library and support
+        # events, and socket management.
+        """
+        """
+    
+    def register(self, Middleware):
+        pass
+
+    def __next_func(self, handler):
+        handler(self.req, self.res, self.__next_func)
 
     def __dispatch(self, req):
         adapter = self.rules.bind_to_environ(req.environ)
-        res = SolaceResponse()
+        self.req = req
+        self.res = SolaceResponse()
         try:
             endpoint, values = adapter.match()
-            req.params = munch.munchify(values)
+            self.req.params = munch.munchify(values)
             if endpoint not in self.views:
                 raise NotFound
-            self.views[endpoint](req, res)
+            self.views[endpoint](self.req, self.res, self.__next_func)
 
-            if res.json:
-                res.content_type = "application/json"
-                res.data = json.dumps(res.json)
-            return res
+            if self.res.json:
+                self.res.content_type = "application/json"
+                self.res.data = json.dumps(self.res.json)
+            return self.res
         except HTTPException as e:
             err = {
                 'code': e.code,
@@ -118,7 +163,7 @@ class App:
             res = Response(json.dumps({"error": err}), e.code)
             res.content_type = 'application/json'
             return res 
-    
+
     def __wsgi_app(self, environ, start_response):
         req = Request(environ)
         res = self.__dispatch(req)
@@ -133,17 +178,17 @@ class DevelopmentServer:
     # that we can support for the DevelopmentServer.
     # https://werkzeug.palletsprojects.com/en/2.0.x/serving/
 
-    def __init__(self, app, host, port, debug = True):
-        self.app = app
+    def __init__(self, api, host = "127.0.0.1", port = 5000, reload = True):
+        self.api = api
         self.host = host
         self.port = port
-        self.debug = debug
+        self.reload = reload
     
     def start(self):
         run_simple(
             self.host, 
             self.port, 
-            self.app, 
-            use_debugger=self.debug, 
-            use_reloader=True
+            self.api, 
+            use_debugger=False,
+            use_reloader=self.reload
         )
